@@ -8,7 +8,9 @@ from apigee import APIGEE_ADMIN_API_URL, auth, console
 CREATE_API_PRODUCT_PATH = '{api_url}/v1/organizations/{org}/apiproducts'
 DELETE_API_PRODUCT_PATH = '{api_url}/v1/organizations/{org}/apiproducts/{name}'
 GET_API_PRODUCT_PATH = '{api_url}/v1/organizations/{org}/apiproducts/{name}'
-LIST_API_PRODUCTS_PATH = '{api_url}/v1/organizations/{org}/apiproducts?expand={expand}&count={count}&startKey={startkey}'
+LIST_API_PRODUCTS_PATH = (
+    '{api_url}/v1/organizations/{org}/apiproducts?expand={expand}&count={count}&startKey={startkey}'
+)
 UPDATE_API_PRODUCT_PATH = '{api_url}/v1/organizations/{org}/apiproducts/{name}'
 
 
@@ -73,7 +75,9 @@ class Apiproducts:
         return resp
 
     def delete_api_product(self):
-        uri = DELETE_API_PRODUCT_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, name=self._apiproduct_name)
+        uri = DELETE_API_PRODUCT_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, name=self._apiproduct_name
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
         resp.raise_for_status()
@@ -87,14 +91,18 @@ class Apiproducts:
         return resp
 
     def list_api_products(self, prefix=None, expand=False, count=1000, startkey="", format='json'):
-        uri = LIST_API_PRODUCTS_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, expand=expand, count=count, startkey=startkey)
+        uri = LIST_API_PRODUCTS_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, expand=expand, count=count, startkey=startkey
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return ApiproductsSerializer().serialize_details(resp, format, prefix=prefix)
 
     def update_api_product(self, request_body):
-        uri = UPDATE_API_PRODUCT_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, name=self._apiproduct_name)
+        uri = UPDATE_API_PRODUCT_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, name=self._apiproduct_name
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         body = json.loads(request_body)
         resp = requests.put(uri, headers=hdrs, json=body)
