@@ -15,17 +15,13 @@ from apigee.utils import (extract_zip, make_dirs, path_exists, paths_exist,
                           split_path, write_zip)
 
 DELETE_API_PROXY_REVISION_PATH = '{api_url}/v1/organizations/{org}/apis/{api_name}/revisions/{revision_number}'
-DEPLOY_API_PROXY_REVISION_PATH = (
-    '{api_url}/v1/organizations/{org}/environments/{environment}/apis/{api_name}/revisions/{revision_number}/deployments?delay={delay}'
-)
+DEPLOY_API_PROXY_REVISION_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/apis/{api_name}/revisions/{revision_number}/deployments?delay={delay}'
 EXPORT_API_PROXY_PATH = '{api_url}/v1/organizations/{org}/apis/{api_name}/revisions/{revision_number}?format=bundle'
 GET_API_PROXY_PATH = '{api_url}/v1/organizations/{org}/apis/{api_name}'
 LIST_API_PROXIES_PATH = '{api_url}/v1/organizations/{org}/apis'
 LIST_API_PROXY_REVISIONS_PATH = '{api_url}/v1/organizations/{org}/apis/{api_name}/revisions'
 UNDEPLOY_API_PROXY_REVISION_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/apis/{api_name}/revisions/{revision_number}/deployments'
-FORCE_UNDEPLOY_API_PROXY_REVISION_PATH = (
-    '{api_url}/v1/organizations/{org}/apis/{api_name}/revisions/{revision_number}/deployments?action=undeploy&env={environment}&force=true'
-)
+FORCE_UNDEPLOY_API_PROXY_REVISION_PATH = '{api_url}/v1/organizations/{org}/apis/{api_name}/revisions/{revision_number}/deployments?action=undeploy&env={environment}&force=true'
 
 
 class ApisSerializer:
@@ -179,12 +175,16 @@ class Apis(IApis, IPull):
     def __init__(self, *args, **kwargs):
         IApis.__init__(self, args[0], args[1])  # auth, org_name
         try:
-            IPull.__init__(self, args[0], args[1], args[2], args[3], **kwargs)  # auth, org_name, revision_number, environment, work_tree=None
+            IPull.__init__(
+                self, args[0], args[1], args[2], args[3], **kwargs
+            )  # auth, org_name, revision_number, environment, work_tree=None
         except IndexError:
             pass
 
     def delete_api_proxy_revision(self, api_name, revision_number):
-        uri = DELETE_API_PROXY_REVISION_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, api_name=api_name, revision_number=revision_number)
+        uri = DELETE_API_PROXY_REVISION_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, api_name=api_name, revision_number=revision_number
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
         resp.raise_for_status()
@@ -192,9 +192,16 @@ class Apis(IApis, IPull):
 
     def deploy_api_proxy_revision(self, api_name, environment, revision_number, delay=0, override=False):
         uri = DEPLOY_API_PROXY_REVISION_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, api_name=api_name, revision_number=revision_number, delay=delay
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            environment=environment,
+            api_name=api_name,
+            revision_number=revision_number,
+            delay=delay,
+        )
+        hdrs = auth.set_header(
+            self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/x-www-form-urlencoded'}
         )
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/x-www-form-urlencoded'})
         resp = requests.post(uri, headers=hdrs, data={'override': 'true' if override else 'false'})
         resp.raise_for_status()
         return resp
@@ -216,13 +223,16 @@ class Apis(IApis, IPull):
         return deployed
 
     def get_undeployed_revisions(self, revisions, deployed, save_last=0):
-        undeployed = [int(rev) for rev in revisions if rev not in deployed]
-        undeployed.sort()
+        undeployed = sorted([int(rev) for rev in revisions if rev not in deployed])
         return undeployed[: -save_last if save_last > 0 else len(undeployed)]
 
     def delete_undeployed_revisions(self, api_name, save_last=0, dry_run=False):
-        details = self.get_deployment_details(Deployments(self._auth, self._org_name, api_name).get_api_proxy_deployment_details().json())
-        undeployed = self.get_undeployed_revisions(self.list_api_proxy_revisions(api_name).json(), self.get_deployed_revisions(details), save_last=save_last)
+        details = self.get_deployment_details(
+            Deployments(self._auth, self._org_name, api_name).get_api_proxy_deployment_details().json()
+        )
+        undeployed = self.get_undeployed_revisions(
+            self.list_api_proxy_revisions(api_name).json(), self.get_deployed_revisions(details), save_last=save_last
+        )
         console.echo(f'Undeployed revisions to be deleted: {undeployed}')
         if dry_run:
             return undeployed
@@ -239,7 +249,9 @@ class Apis(IApis, IPull):
         fs_write=True,
         output_file=None,
     ):
-        uri = EXPORT_API_PROXY_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, api_name=api_name, revision_number=revision_number)
+        uri = EXPORT_API_PROXY_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, api_name=api_name, revision_number=revision_number
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
@@ -271,7 +283,11 @@ class Apis(IApis, IPull):
 
     def undeploy_api_proxy_revision(self, api_name, environment, revision_number):
         uri = UNDEPLOY_API_PROXY_REVISION_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, api_name=api_name, revision_number=revision_number
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            environment=environment,
+            api_name=api_name,
+            revision_number=revision_number,
         )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
@@ -280,7 +296,11 @@ class Apis(IApis, IPull):
 
     def force_undeploy_api_proxy_revision(self, api_name, environment, revision_number):
         uri = FORCE_UNDEPLOY_API_PROXY_REVISION_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, api_name=api_name, revision_number=revision_number, environment=environment
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            api_name=api_name,
+            revision_number=revision_number,
+            environment=environment,
         )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
@@ -312,7 +332,11 @@ class Apis(IApis, IPull):
             keyvaluemap_file = str(Path(self._keyvaluemaps_dir) / keyvaluemap)
             if not force:
                 path_exists(os.path.relpath(keyvaluemap_file))
-            resp = Keyvaluemaps(self._auth, self._org_name, keyvaluemap).get_keyvaluemap_in_an_environment(environment).text
+            resp = (
+                Keyvaluemaps(self._auth, self._org_name, keyvaluemap)
+                .get_keyvaluemap_in_an_environment(environment)
+                .text
+            )
             console.echo(resp, expc_verbosity=1)
             with open(keyvaluemap_file, 'w') as f:
                 f.write(resp)
