@@ -13,8 +13,12 @@ DELETE_DEVELOPER_APP_PATH = '{api_url}/v1/organizations/{org}/developers/{develo
 CREATE_EMPTY_DEVELOPER_APP_PATH = CREATE_DEVELOPER_APP_PATH
 GET_DEVELOPER_APP_DETAILS_PATH = '{api_url}/v1/organizations/{org}/developers/{developer}/apps/{name}'
 LIST_DEVELOPER_APPS_PATH = '{api_url}/v1/organizations/{org}/developers/{developer}/apps'
-DELETE_KEY_FOR_A_DEVELOPER_APP_PATH = '{api_url}/v1/organizations/{org}/developers/{developer}/apps/{name}/keys/{consumer_key}'
-CREATE_A_CONSUMER_KEY_AND_SECRET_PATH = '{api_url}/v1/organizations/{org}/developers/{developer}/apps/{name}/keys/create'
+DELETE_KEY_FOR_A_DEVELOPER_APP_PATH = (
+    '{api_url}/v1/organizations/{org}/developers/{developer}/apps/{name}/keys/{consumer_key}'
+)
+CREATE_A_CONSUMER_KEY_AND_SECRET_PATH = (
+    '{api_url}/v1/organizations/{org}/developers/{developer}/apps/{name}/keys/create'
+)
 ADD_API_PRODUCT_TO_KEY_PATH = '{api_url}/v1/organizations/{org}/developers/{developer}/apps/{name}/keys/{consumer_key}'
 
 
@@ -79,14 +83,18 @@ class Apps:
         return resp
 
     def delete_developer_app(self, developer):
-        uri = DELETE_DEVELOPER_APP_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer=developer, name=self._app_name)
+        uri = DELETE_DEVELOPER_APP_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer=developer, name=self._app_name
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
     def create_empty_developer_app(self, developer, display_name="", callback_url=""):
-        uri = CREATE_EMPTY_DEVELOPER_APP_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer=developer)
+        uri = CREATE_EMPTY_DEVELOPER_APP_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer=developer
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         body = {
             'name': self._app_name,
@@ -106,7 +114,9 @@ class Apps:
         return self.get_developer_app_details(developer)
 
     def get_developer_app_details(self, developer):
-        uri = GET_DEVELOPER_APP_DETAILS_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer=developer, name=self._app_name)
+        uri = GET_DEVELOPER_APP_DETAILS_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer=developer, name=self._app_name
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
@@ -123,15 +133,23 @@ class Apps:
         resp.raise_for_status()
         return AppsSerializer().serialize_details(resp, format, prefix=prefix)
 
-    def list_apps_for_all_developers(self, list_of_developers, prefix=None, expand=False, count=1000, startkey="", format='dict', progress_bar=False):
+    def list_apps_for_all_developers(
+        self, list_of_developers, prefix=None, expand=False, count=1000, startkey="", format='dict', progress_bar=False
+    ):
         apps = {}
         for developer in list_of_developers:
-            apps[developer] = self.list_developer_apps(developer, prefix=prefix, expand=expand, count=count, startkey=startkey, format=format)
+            apps[developer] = self.list_developer_apps(
+                developer, prefix=prefix, expand=expand, count=count, startkey=startkey, format=format
+            )
         return apps
 
     def delete_key_for_a_developer_app(self, developer, consumer_key):
         uri = DELETE_KEY_FOR_A_DEVELOPER_APP_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer=developer, name=self._app_name, consumer_key=consumer_key
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            developer=developer,
+            name=self._app_name,
+            consumer_key=consumer_key,
         )
         hdrs = auth.set_header(self._auth, {'Accept': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
@@ -139,15 +157,29 @@ class Apps:
         return resp
 
     def create_a_consumer_key_and_secret(
-        self, developer, consumer_key=None, consumer_secret=None, key_length=32, secret_length=32, key_suffix=None, key_delimiter='-', products=[]
+        self,
+        developer,
+        consumer_key=None,
+        consumer_secret=None,
+        key_length=32,
+        secret_length=32,
+        key_suffix=None,
+        key_delimiter='-',
+        products=[],
     ):
-        uri = CREATE_A_CONSUMER_KEY_AND_SECRET_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer=developer, name=self._app_name)
+        uri = CREATE_A_CONSUMER_KEY_AND_SECRET_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer=developer, name=self._app_name
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         # app = self.get_developer_app_details(developer)
         if not consumer_key:
-            consumer_key = "".join(random.SystemRandom().choice(string.ascii_letters + string.digits) for _ in range(key_length))
+            consumer_key = "".join(
+                random.SystemRandom().choice(string.ascii_letters + string.digits) for _ in range(key_length)
+            )
         if not consumer_secret:
-            consumer_secret = "".join(random.SystemRandom().choice(string.ascii_letters + string.digits) for _ in range(secret_length))
+            consumer_secret = "".join(
+                random.SystemRandom().choice(string.ascii_letters + string.digits) for _ in range(secret_length)
+            )
         if key_suffix:
             consumer_key += key_delimiter
             consumer_key += key_suffix
@@ -164,7 +196,11 @@ class Apps:
 
     def add_api_product_to_key(self, developer, consumer_key, request_body):
         uri = ADD_API_PRODUCT_TO_KEY_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, developer=developer, name=self._app_name, consumer_key=consumer_key
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            developer=developer,
+            name=self._app_name,
+            consumer_key=consumer_key,
         )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         body = json.loads(request_body)
@@ -190,5 +226,7 @@ class Apps:
                 consumer_key = cred['consumerKey']
                 consumer_secret = cred['consumerSecret']
                 products = [product['apiproduct'] for product in cred['apiProducts']]
-                resp = self.create_a_consumer_key_and_secret(app['developerId'], consumer_key=consumer_key, consumer_secret=consumer_secret, products=products)
+                resp = self.create_a_consumer_key_and_secret(
+                    app['developerId'], consumer_key=consumer_key, consumer_secret=consumer_secret, products=products
+                )
         return self.get_developer_app_details(app['developerId'])
