@@ -35,7 +35,7 @@ class Backups:
         self.fs_write = fs_write
         if not isinstance(apis, set):
             apis = set(apis)
-        self.apis = apis
+        self.apis = sorted(apis)
         self.environments = environments
         self.snapshot_data = empty_snapshot()
         self.snapshot_size = 0
@@ -80,6 +80,7 @@ class Backups:
                     / (api + '.json')
                 ),
                 fs_write=self.fs_write,
+                indent=2
             )
         return self.snapshot_data.apis
 
@@ -120,6 +121,7 @@ class Backups:
                     / 'keyvaluemaps.json'
                 ),
                 fs_write=self.fs_write,
+                indent=2
             )
         return self.snapshot_data.keyvaluemaps
 
@@ -158,6 +160,7 @@ class Backups:
                     / 'targetservers.json'
                 ),
                 fs_write=self.fs_write,
+                indent=2
             )
         return self.snapshot_data.targetservers
 
@@ -202,6 +205,7 @@ class Backups:
                     / 'caches.json'
                 ),
                 fs_write=self.fs_write,
+                indent=2
             )
         return self.snapshot_data.caches
 
@@ -233,6 +237,7 @@ class Backups:
                 / 'developers.json'
             ),
             fs_write=self.fs_write,
+            indent=2
         )
         return self.snapshot_data.developers
 
@@ -263,6 +268,7 @@ class Backups:
                 / 'apiproducts.json'
             ),
             fs_write=self.fs_write,
+            indent=2
         )
         return self.snapshot_data.apiproducts
 
@@ -301,6 +307,7 @@ class Backups:
                     / (app + '.json')
                 ),
                 fs_write=self.fs_write,
+                indent=2
             )
         return self.snapshot_data.apps
 
@@ -336,11 +343,12 @@ class Backups:
                 / 'userroles.json'
             ),
             fs_write=self.fs_write,
+            indent=2
         )
         return self.snapshot_data.userroles
 
     def _get_users_for_a_role(self, role_name):
-        return Userroles(self.auth, self.org_name, role_name).get_users_for_a_role().text
+        return Userroles(self.auth, self.org_name, role_name).get_users_for_a_role().json()
 
     @staticmethod
     def _sort_lists_in_permissions(resource_permissions):
@@ -362,6 +370,7 @@ class Backups:
                 self._get_users_for_a_role(role_name),
                 str(Path(self.target_directory) / self.org_name / 'userroles' / role_name / 'users.json'),
                 fs_write=self.fs_write,
+                indent=2
             )
         except HTTPError as e:
             console.echo(f'Ignoring {type(e).__name__} {e.response.status_code} error for User Role ({role_name}) users')
@@ -403,37 +412,12 @@ class Backups:
         return count
 
     def get_snapshots(self):
-        if 'apis' in self.apis:
-            console.echo('Retrieving API Proxies listing (this may take a while)... ', end='', flush=True)
-            self.download_apis_snapshot()
-            console.echo('Done')
-        if 'keyvaluemaps' in self.apis:
-            console.echo('Retrieving KeyValueMaps listing... ', end='', flush=True)
-            self.download_keyvaluemaps_snapshot()
-            console.echo('Done')
-        if 'targetservers' in self.apis:
-            console.echo('Retrieving TargetServers listing... ', end='', flush=True)
-            self.download_targetservers_snapshot()
-            console.echo('Done')
-        if 'caches' in self.apis:
-            console.echo('Retrieving Caches listing... ', end='', flush=True)
-            self.download_caches_snapshot()
-            console.echo('Done')
-        if 'developers' in self.apis:
-            console.echo('Retrieving Developers listing... ', end='', flush=True)
-            self.download_developers_snapshot()
-            console.echo('Done')
-        if 'apiproducts' in self.apis:
-            console.echo('Retrieving API Products listing... ', end='', flush=True)
-            self.download_apiproducts_snapshot()
-            console.echo('Done')
-        if 'apps' in self.apis:
-            console.echo('Retrieving Developer Apps listing (this may take a while)... ', end='', flush=True)
-            self.download_apps_snapshot()
-            console.echo('Done')
-        if 'userroles' in self.apis:
-            console.echo('Retrieving User Roles listing... ', end='', flush=True)
-            self.download_userroles_snapshot()
+        for api in self.apis:
+            if api in {'apis', 'apps'}:
+                console.echo(f'Retrieving {api} listing (this may take a while)... ', end='', flush=True)
+            else:
+                console.echo(f'Retrieving {api} listing... ', end='', flush=True)
+            getattr(self, f'download_{api}_snapshot')()
             console.echo('Done')
         self.snapshot_size = self._calculate_snapshot_size()
         return self.snapshot_data
@@ -441,22 +425,8 @@ class Backups:
     def take_snapshot(self):
         self.get_snapshots()
         console.echo('Generating snapshot files...')
-        if 'apis' in self.apis:
-            self.download_apis()
-        if 'keyvaluemaps' in self.apis:
-            self.download_keyvaluemaps()
-        if 'targetservers' in self.apis:
-            self.download_targetservers()
-        if 'caches' in self.apis:
-            self.download_caches()
-        if 'developers' in self.apis:
-            self.download_developers()
-        if 'apiproducts' in self.apis:
-            self.download_apiproducts()
-        if 'apps' in self.apis:
-            self.download_apps()
-        if 'userroles' in self.apis:
-            self.download_userroles()
+        for api in self.apis:
+            getattr(self, f'download_{api}')()
         self.progress_bar.close()
         console.echo('Done.')
         return self.snapshot_data
