@@ -15,8 +15,14 @@ def caches():
     pass
 
 
-def _clear_all_cache_entries(username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).clear_all_cache_entries(environment).text
+def _clear_all_cache_entries(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs
+):
+    return (
+        Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .clear_all_cache_entries(environment)
+        .text
+    )
 
 
 @caches.command(help='Clears all cache entries.')
@@ -29,8 +35,14 @@ def clear(*args, **kwargs):
     console.echo(_clear_all_cache_entries(*args, **kwargs))
 
 
-def _clear_a_cache_entry(username, password, mfa_secret, token, zonename, org, profile, name, environment, entry, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).clear_a_cache_entry(environment, entry).text
+def _clear_a_cache_entry(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, entry, **kwargs
+):
+    return (
+        Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .clear_a_cache_entry(environment, entry)
+        .text
+    )
 
 
 @caches.command(help='Clears a cache entry, which is identified by the full CacheKey prefix and value.')
@@ -44,8 +56,14 @@ def clear_entry(*args, **kwargs):
     console.echo(_clear_a_cache_entry(*args, **kwargs))
 
 
-def _create_a_cache_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, name, environment, body, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).create_a_cache_in_an_environment(environment, body).text
+def _create_a_cache_in_an_environment(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, body, **kwargs
+):
+    return (
+        Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .create_a_cache_in_an_environment(environment, body)
+        .text
+    )
 
 
 @caches.command(
@@ -61,11 +79,19 @@ def create(*args, **kwargs):
     console.echo(_create_a_cache_in_an_environment(*args, **kwargs))
 
 
-def _get_information_about_a_cache(username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).get_information_about_a_cache(environment).text
+def _get_information_about_a_cache(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs
+):
+    return (
+        Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .get_information_about_a_cache(environment)
+        .text
+    )
 
 
-@caches.command(help='Gets information about a cache. The response might contain a property named persistent. That property is no longer used by Edge.')
+@caches.command(
+    help='Gets information about a cache. The response might contain a property named persistent. That property is no longer used by Edge.'
+)
 @common_auth_options
 @common_silent_options
 @common_verbose_options
@@ -75,8 +101,12 @@ def get(*args, **kwargs):
     console.echo(_get_information_about_a_cache(*args, **kwargs))
 
 
-def _list_caches_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, environment, prefix=None, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, None).list_caches_in_an_environment(environment, prefix=prefix)
+def _list_caches_in_an_environment(
+    username, password, mfa_secret, token, zonename, org, profile, environment, prefix=None, **kwargs
+):
+    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, None).list_caches_in_an_environment(
+        environment, prefix=prefix
+    )
 
 
 @caches.command(help='List caches in an environment.')
@@ -89,8 +119,14 @@ def list(*args, **kwargs):
     console.echo(_list_caches_in_an_environment(*args, **kwargs))
 
 
-def _update_a_cache_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, name, environment, body, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).update_a_cache_in_an_environment(environment, body).text
+def _update_a_cache_in_an_environment(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, body, **kwargs
+):
+    return (
+        Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .update_a_cache_in_an_environment(environment, body)
+        .text
+    )
 
 
 @caches.command(
@@ -129,6 +165,8 @@ def _push_cache(username, password, mfa_secret, token, zonename, org, profile, e
 @common_silent_options
 @common_verbose_options
 @click.option('-e', '--environment', help='environment', required=True)
-@click.option('-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True)
+@click.option(
+    '-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True
+)
 def push(*args, **kwargs):
     _push_cache(*args, **kwargs)
