@@ -1,10 +1,15 @@
+import sys
+
 import click
 
-from apigee import console
+from apigee import APIGEE_CLI_SYMMETRIC_KEY, console
 from apigee.auth import common_auth_options, gen_auth
+from apigee.crypto import (ENCRYPTED_HEADER_BEGIN, ENCRYPTED_HEADER_END,
+                           decrypt_message, encrypt_message, is_encrypted)
 from apigee.keyvaluemaps.keyvaluemaps import Keyvaluemaps
 from apigee.prefix import common_prefix_options
 from apigee.silent import common_silent_options
+from apigee.utils import read_file, write_file
 from apigee.verbose import common_verbose_options
 
 
@@ -15,8 +20,14 @@ def keyvaluemaps():
     pass
 
 
-def _create_keyvaluemap_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, name, environment, body, **kwargs):
-    return Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, name).create_keyvaluemap_in_an_environment(environment, body).text
+def _create_keyvaluemap_in_an_environment(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, body, **kwargs
+):
+    return (
+        Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .create_keyvaluemap_in_an_environment(environment, body)
+        .text
+    )
 
 
 @keyvaluemaps.command(help='Creates a key value map in an environment.')
@@ -30,8 +41,14 @@ def create(*args, **kwargs):
     console.echo(_create_keyvaluemap_in_an_environment(*args, **kwargs))
 
 
-def _delete_keyvaluemap_from_an_environment(username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs):
-    return Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, name).delete_keyvaluemap_from_an_environment(environment).text
+def _delete_keyvaluemap_from_an_environment(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs
+):
+    return (
+        Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .delete_keyvaluemap_from_an_environment(environment)
+        .text
+    )
 
 
 @keyvaluemaps.command(help='Deletes a key/value map and all associated entries from an environment.')
@@ -44,7 +61,9 @@ def delete(*args, **kwargs):
     console.echo(_delete_keyvaluemap_from_an_environment(*args, **kwargs))
 
 
-def _delete_keyvaluemap_entry_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, name, environment, entry_name, **kwargs):
+def _delete_keyvaluemap_entry_in_an_environment(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, entry_name, **kwargs
+):
     return (
         Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
         .delete_keyvaluemap_entry_in_an_environment(environment, entry_name)
@@ -52,7 +71,9 @@ def _delete_keyvaluemap_entry_in_an_environment(username, password, mfa_secret,
     )
 
 
-@keyvaluemaps.command(help='Deletes a specific key/value map entry in an environment by name, along with associated entries.')
+@keyvaluemaps.command(
+    help='Deletes a specific key/value map entry in an environment by name, along with associated entries.'
+)
 @common_auth_options
 @common_silent_options
 @common_verbose_options
@@ -63,8 +84,14 @@ def delete_entry(*args, **kwargs):
     console.echo(_delete_keyvaluemap_entry_in_an_environment(*args, **kwargs))
 
 
-def _get_keyvaluemap_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs):
-    return Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, name).get_keyvaluemap_in_an_environment(environment).text
+def _get_keyvaluemap_in_an_environment(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs
+):
+    return (
+        Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .get_keyvaluemap_in_an_environment(environment)
+        .text
+    )
 
 
 @keyvaluemaps.command(help='Gets a KeyValueMap (KVM) in an environment by name, along with the keys and values.')
@@ -98,8 +125,12 @@ def get_value(*args, **kwargs):
     console.echo(_get_a_keys_value_in_an_environment_scoped_keyvaluemap(*args, **kwargs))
 
 
-def _list_keyvaluemaps_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, environment, prefix=None, **kwargs):
-    return Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, None).list_keyvaluemaps_in_an_environment(environment, prefix=prefix)
+def _list_keyvaluemaps_in_an_environment(
+    username, password, mfa_secret, token, zonename, org, profile, environment, prefix=None, **kwargs
+):
+    return Keyvaluemaps(
+        gen_auth(username, password, mfa_secret, token, zonename), org, None
+    ).list_keyvaluemaps_in_an_environment(environment, prefix=prefix)
 
 
 @keyvaluemaps.command(
@@ -114,8 +145,14 @@ def list(*args, **kwargs):
     console.echo(_list_keyvaluemaps_in_an_environment(*args, **kwargs))
 
 
-def _update_keyvaluemap_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, name, environment, body, **kwargs):
-    return Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, name).update_keyvaluemap_in_an_environment(environment, body).text
+def _update_keyvaluemap_in_an_environment(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, body, **kwargs
+):
+    return (
+        Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .update_keyvaluemap_in_an_environment(environment, body)
+        .text
+    )
 
 
 @keyvaluemaps.command(
@@ -156,7 +193,18 @@ def create_entry(*args, **kwargs):
 
 
 def _update_an_entry_in_an_environment_scoped_kvm(
-    username, password, mfa_secret, token, zonename, org, profile, name, environment, entry_name, updated_value, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    environment,
+    entry_name,
+    updated_value,
+    **kwargs
 ):
     return (
         Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
@@ -198,7 +246,12 @@ def _list_keys_in_an_environment_scoped_keyvaluemap(
 @common_verbose_options
 @click.option('-n', '--name', help='name', required=True)
 @click.option('-e', '--environment', help='environment', required=True)
-@click.option('--startkey', default="", show_default=True, help='To filter the keys that are returned, enter the name of a key that the list will start with.')
+@click.option(
+    '--startkey',
+    default="",
+    show_default=True,
+    help='To filter the keys that are returned, enter the name of a key that the list will start with.',
+)
 @click.option(
     '--count',
     type=click.INT,
@@ -211,8 +264,12 @@ def list_keys(*args, **kwargs):
     console.echo(_list_keys_in_an_environment_scoped_keyvaluemap(*args, **kwargs))
 
 
-def _push_keyvaluemap(username, password, mfa_secret, token, zonename, org, profile, environment, file, **kwargs):
-    return Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, None).push_keyvaluemap(environment, file)
+def _push_keyvaluemap(
+    username, password, mfa_secret, token, zonename, org, profile, environment, file, symmetric_key, **kwargs
+):
+    return Keyvaluemaps(gen_auth(username, password, mfa_secret, token, zonename), org, None).push_keyvaluemap(
+        environment, file, secret=symmetric_key
+    )
 
 
 @keyvaluemaps.command(
@@ -222,6 +279,49 @@ def _push_keyvaluemap(username, password, mfa_secret, token, zonename, org, prof
 @common_silent_options
 @common_verbose_options
 @click.option('-e', '--environment', help='environment', required=True)
-@click.option('-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True)
+@click.option(
+    '-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True
+)
+@click.option('--symmetric-key', default=APIGEE_CLI_SYMMETRIC_KEY, help='symmetric secret key for decrypting')
 def push(*args, **kwargs):
     _push_keyvaluemap(*args, **kwargs)
+
+
+@keyvaluemaps.command(name='encrypt', help='Use symmetric GPG (AES256) to encrypt KVM file in a custom format.')
+@common_silent_options
+@common_verbose_options
+@click.option(
+    '-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True
+)
+@click.option('--symmetric-key', required=True, help='symmetric secret key for encrypting')
+def encrypt_file(symmetric_key, file, verbose, silent):
+    contents = read_file(file, type='json')
+    decrypted_count = 0
+    console.echo('Encrypting... ', end='', flush=True)
+    contents, decrypted_count = Keyvaluemaps.encrypt_keyvaluemap(contents, symmetric_key)
+    if decrypted_count:
+        write_file(contents, file, indent=2)
+        console.echo('Done')
+        return contents
+    console.echo('None')
+    return ''
+
+
+@keyvaluemaps.command(name='decrypt', help='Use symmetric GPG (AES256) to decrypt KVM file in a custom format.')
+@common_silent_options
+@common_verbose_options
+@click.option(
+    '-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True
+)
+@click.option('--symmetric-key', required=True, help='symmetric secret key for decrypting')
+def decrypt_file(symmetric_key, file, verbose, silent):
+    contents = read_file(file, type='json')
+    decrypted_count = 0
+    console.echo('Decrypting... ', end='', flush=True)
+    contents, decrypted_count = Keyvaluemaps.decrypt_keyvaluemap(contents, symmetric_key)
+    if decrypted_count:
+        write_file(contents, file, indent=2)
+        console.echo('Done')
+        return contents
+    console.echo('None')
+    return ''
