@@ -15,10 +15,14 @@ def sharedflows():
 
 
 def _get_a_list_of_shared_flows(username, password, mfa_secret, token, zonename, org, profile, prefix=None, **kwargs):
-    return Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).get_a_list_of_shared_flows(prefix=prefix)
+    return Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).get_a_list_of_shared_flows(
+        prefix=prefix
+    )
 
 
-@sharedflows.command(help='Gets an array of the names of shared flows in the organization. The response is a simple array of strings.')
+@sharedflows.command(
+    help='Gets an array of the names of shared flows in the organization. The response is a simple array of strings.'
+)
 @common_auth_options
 @common_prefix_options
 @common_silent_options
@@ -28,7 +32,11 @@ def list(*args, **kwargs):
 
 
 def _import_a_shared_flow(username, password, mfa_secret, token, zonename, org, profile, file, name, **kwargs):
-    return Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).import_a_shared_flow(file, name).text
+    return (
+        Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .import_a_shared_flow(file, name)
+        .text
+    )
 
 
 @sharedflows.command(
@@ -68,7 +76,22 @@ def get(*args, **kwargs):
     console.echo(_get_a_shared_flow(*args, **kwargs))
 
 
-def _deploy_a_shared_flow(username, password, mfa_secret, token, zonename, org, profile, environment, name, revision_number, override, delay, file, **kwargs):
+def _deploy_a_shared_flow(
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    environment,
+    name,
+    revision_number,
+    override,
+    delay,
+    file,
+    **kwargs
+):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
         .deploy_a_shared_flow(environment, name, revision_number, override=override, delay=delay, shared_flow_file=file)
@@ -110,8 +133,14 @@ def deploy(*args, **kwargs):
     console.echo(_deploy_a_shared_flow(*args, **kwargs))
 
 
-def _undeploy_a_shared_flow(username, password, mfa_secret, token, zonename, org, profile, environment, name, revision_number, **kwargs):
-    return Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).undeploy_a_shared_flow(environment, name, revision_number).text
+def _undeploy_a_shared_flow(
+    username, password, mfa_secret, token, zonename, org, profile, environment, name, revision_number, **kwargs
+):
+    return (
+        Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .undeploy_a_shared_flow(environment, name, revision_number)
+        .text
+    )
 
 
 @sharedflows.command(help='Undeploys a shared flow revision from an environment.')
@@ -125,8 +154,14 @@ def undeploy(*args, **kwargs):
     console.echo(_undeploy_a_shared_flow(*args, **kwargs))
 
 
-def _get_deployment_environments_for_shared_flows(username, password, mfa_secret, token, zonename, org, profile, name, revision_number, **kwargs):
-    return Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).get_deployment_environments_for_shared_flows(name, revision_number).text
+def _get_deployment_environments_for_shared_flows(
+    username, password, mfa_secret, token, zonename, org, profile, name, revision_number, **kwargs
+):
+    return (
+        Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .get_deployment_environments_for_shared_flows(name, revision_number)
+        .text
+    )
 
 
 @sharedflows.command(help='Gets an array of the environments to which the shared flow is deployed.')
@@ -150,8 +185,14 @@ def _delete_a_shared_flow(self, shared_flow_name):
 #     pass
 
 
-def _get_the_shared_flow_attached_to_a_flow_hook(username, password, mfa_secret, token, zonename, org, profile, environment, flow_hook, **kwargs):
-    return Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).get_the_shared_flow_attached_to_a_flow_hook(environment, flow_hook).text
+def _get_the_shared_flow_attached_to_a_flow_hook(
+    username, password, mfa_secret, token, zonename, org, profile, environment, flow_hook, **kwargs
+):
+    return (
+        Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .get_the_shared_flow_attached_to_a_flow_hook(environment, flow_hook)
+        .text
+    )
 
 
 @sharedflows.command(
@@ -167,7 +208,11 @@ def get_flow_hook(*args, **kwargs):
 
 
 def _get_shared_flow_deployments(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
-    return Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).get_shared_flow_deployments(name).text
+    return (
+        Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .get_shared_flow_deployments(name)
+        .text
+    )
 
 
 @sharedflows.command(help='View all shared flow deployments.')
@@ -180,7 +225,9 @@ def get_deployments(*args, **kwargs):
 
 
 def _get_shared_flow_revisions(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
-    return Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).get_shared_flow_revisions(name).text
+    return (
+        Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).get_shared_flow_revisions(name).text
+    )
 
 
 @sharedflows.command(help='List the revisions of a shared flow.')
