@@ -5,11 +5,19 @@ import requests
 from apigee import APIGEE_ADMIN_API_URL, auth
 
 ADD_A_USER_TO_A_ROLE_PATH = '{api_url}/v1/organizations/{org}/userroles/{role_name}/users?id={user_email}'
-ADD_PERMISSIONS_FOR_A_RESOURCE_TO_A_USER_ROLE_PATH = '{api_url}/v1/organizations/{org}/userroles/{role_name}/permissions'
-ADD_PERMISSIONS_FOR_MULTIPLE_RESOURCES_TO_A_USER_ROLE_PATH = '{api_url}/v1/organizations/{org}/userroles/{role_name}/resourcepermissions'
+ADD_PERMISSIONS_FOR_A_RESOURCE_TO_A_USER_ROLE_PATH = (
+    '{api_url}/v1/organizations/{org}/userroles/{role_name}/permissions'
+)
+ADD_PERMISSIONS_FOR_MULTIPLE_RESOURCES_TO_A_USER_ROLE_PATH = (
+    '{api_url}/v1/organizations/{org}/userroles/{role_name}/resourcepermissions'
+)
 CREATE_A_USER_ROLE_IN_AN_ORGANIZATION_PATH = '{api_url}/v1/organizations/{org}/userroles'
-DELETE_A_PERMISSION_FOR_A_RESOURCE_PATH = '{api_url}/v1/organizations/{org}/userroles/{role_name}/permissions/{permission}?path={resource_path}'
-DELETE_RESOURCE_FROM_PERMISSIONS_PATH = '{api_url}/v1/organizations/{org}/userroles/{role_name}/permissions?path={resource_path}&delete=true'
+DELETE_A_PERMISSION_FOR_A_RESOURCE_PATH = (
+    '{api_url}/v1/organizations/{org}/userroles/{role_name}/permissions/{permission}?path={resource_path}'
+)
+DELETE_RESOURCE_FROM_PERMISSIONS_PATH = (
+    '{api_url}/v1/organizations/{org}/userroles/{role_name}/permissions?path={resource_path}&delete=true'
+)
 DELETE_A_USER_ROLE_PATH = '{api_url}/v1/organizations/{org}/userroles/{role_name}'
 GET_A_ROLE_PATH = '{api_url}/v1/organizations/{org}/userroles/{role_name}'
 GET_RESOURCE_PERMISSIONS_FOR_A_SPECIFIC_ROLE_PATH = '{api_url}/v1/organizations/{org}/userroles/{role_name}/permissions'
@@ -57,14 +65,20 @@ class Userroles:
         self._role_name = value
 
     def add_a_user_to_a_role(self, user_email):
-        uri = ADD_A_USER_TO_A_ROLE_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name, user_email=user_email)
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/x-www-form-urlencoded'})
+        uri = ADD_A_USER_TO_A_ROLE_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name, user_email=user_email
+        )
+        hdrs = auth.set_header(
+            self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/x-www-form-urlencoded'}
+        )
         resp = requests.post(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
     def add_permissions_for_a_resource_to_a_user_role(self, request_body):
-        uri = ADD_PERMISSIONS_FOR_A_RESOURCE_TO_A_USER_ROLE_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name)
+        uri = ADD_PERMISSIONS_FOR_A_RESOURCE_TO_A_USER_ROLE_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         body = json.loads(request_body)
         resp = requests.post(uri, headers=hdrs, json=body)
@@ -72,8 +86,12 @@ class Userroles:
         return resp
 
     def add_permissions_for_multiple_resources_to_a_user_role(self, request_body):
-        uri = f'{APIGEE_ADMIN_API_URL}/v1/organizations/{self._org_name}/userroles/{self._role_name}/resourcepermissions'
-        uri = ADD_PERMISSIONS_FOR_MULTIPLE_RESOURCES_TO_A_USER_ROLE_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name)
+        uri = (
+            f'{APIGEE_ADMIN_API_URL}/v1/organizations/{self._org_name}/userroles/{self._role_name}/resourcepermissions'
+        )
+        uri = ADD_PERMISSIONS_FOR_MULTIPLE_RESOURCES_TO_A_USER_ROLE_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         body = json.loads(request_body)
         resp = requests.post(uri, headers=hdrs, json=body)
@@ -93,9 +111,15 @@ class Userroles:
 
     def delete_a_permission_for_a_resource(self, permission, resource_path):
         uri = DELETE_A_PERMISSION_FOR_A_RESOURCE_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name, permission=permission, resource_path=resource_path
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            role_name=self._role_name,
+            permission=permission,
+            resource_path=resource_path,
+        )
+        hdrs = auth.set_header(
+            self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/octet-stream'}
         )
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/octet-stream'})
         resp = requests.delete(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
@@ -104,14 +128,20 @@ class Userroles:
         uri = DELETE_RESOURCE_FROM_PERMISSIONS_PATH.format(
             api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name, resource_path=resource_path
         )
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/octet-stream'})
+        hdrs = auth.set_header(
+            self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/octet-stream'}
+        )
         resp = requests.delete(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
     def delete_a_user_role(self):
-        uri = DELETE_A_USER_ROLE_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name)
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/x-www-form-urlencoded'})
+        uri = DELETE_A_USER_ROLE_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name
+        )
+        hdrs = auth.set_header(
+            self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/x-www-form-urlencoded'}
+        )
         resp = requests.delete(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
@@ -124,23 +154,31 @@ class Userroles:
         return resp
 
     def get_resource_permissions_for_a_specific_role(self, resource_path=""):
-        uri = GET_RESOURCE_PERMISSIONS_FOR_A_SPECIFIC_ROLE_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name)
+        uri = GET_RESOURCE_PERMISSIONS_FOR_A_SPECIFIC_ROLE_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name
+        )
         if resource_path:
             uri += f'?path={resource_path}'
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/octet-stream'})
+        hdrs = auth.set_header(
+            self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/octet-stream'}
+        )
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
     def get_users_for_a_role(self):
-        uri = GET_USERS_FOR_A_ROLE_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name)
+        uri = GET_USERS_FOR_A_ROLE_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
     def list_permissions_for_a_resource(self):
-        uri = LIST_PERMISSIONS_FOR_A_RESOURCE_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name)
+        uri = LIST_PERMISSIONS_FOR_A_RESOURCE_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
@@ -154,7 +192,9 @@ class Userroles:
         return resp
 
     def remove_user_membership_in_role(self, user_email):
-        uri = REMOVE_USER_MEMBERSHIP_IN_ROLE_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name, user_email=user_email)
+        uri = REMOVE_USER_MEMBERSHIP_IN_ROLE_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name, user_email=user_email
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
         resp.raise_for_status()
@@ -162,15 +202,23 @@ class Userroles:
 
     def verify_a_user_roles_permission_on_a_specific_RBAC_resource(self, permission, resource_path):
         uri = VERIFY_A_USER_ROLES_PERMISSION_ON_A_SPECIFIC_RBAC_RESOURCE_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name, permission=permission, resource_path=resource_path
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            role_name=self._role_name,
+            permission=permission,
+            resource_path=resource_path,
+        )
+        hdrs = auth.set_header(
+            self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/octet-stream'}
         )
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/octet-stream'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
     def verify_user_role_membership(self, user_email):
-        uri = VERIFY_USER_ROLE_MEMBERSHIP_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name, user_email=user_email)
+        uri = VERIFY_USER_ROLE_MEMBERSHIP_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, role_name=self._role_name, user_email=user_email
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
